@@ -6,6 +6,8 @@ fn main() {
         // Windows::Win32::Foundation::HINSTANCE,
         // Windows::Win32::System::ProcessStatus::K32EnumProcesses,
         // Windows::Win32::System::ProcessStatus::K32GetModuleBaseNameW,
+        Windows::Win32::System::Memory::VirtualAlloc,
+        Windows::Win32::System::Memory::VirtualFree,
     }
     ;
 }
\ No newline at end of file
